@@ -46,19 +46,19 @@ def toJsonDate(obj):
     obj = datetime.datetime(*obj.timetuple()[:-3])
   # is datetime naive or aware
   if obj.tzinfo is not None and obj.tzinfo.utcoffset(obj) is not None:
-    return obj.astimezone(_utc).isoformat("T").replace("+00:00", "Z")
+    return obj.astimezone(_utc).isoformat('T').replace('+00:00', 'Z')
   else:
-    return obj.isoformat("T") + "Z"
+    return obj.isoformat('T') + 'Z'
 
 def fromJsonDate(s):
   if not s:
     return None
   
   try:
-    result = datetime.datetime.strptime(s, "%Y-%m-%dT%H:%M:%S.%fZ")
+    result = datetime.datetime.strptime(s, '%Y-%m-%dT%H:%M:%S.%fZ')
   except ValueError:
     # IE8 JSON implementation produces date without miliseconds
-    result = datetime.datetime.strptime(s, "%Y-%m-%dT%H:%M:%SZ")
+    result = datetime.datetime.strptime(s, '%Y-%m-%dT%H:%M:%SZ')
 
   return result.replace(tzinfo = _utc)
 
