@@ -1,5 +1,24 @@
 '''
 @author: saaj
+
+The package's test suite sets the warning filters explicitly. Warnings are converted 
+to exceptions.
+
+There are several supposed ways to launch the test suite:
+
+  1) PyDev ``PydevTextTestRunner``
+  2) ``setuptools.command.test``command, directly or via ``tox``
+  3) ``unittest`` direct module invokation
+
+Because Python warning settings vary across these three, some normalization is required to 
+produce the same output. The issue is that there is no other easy way to prevent ``unittest`` 
+from settings ``default`` action warning filter, ``unittest.main.TestProgram.warnings``. 
+See ``unittest.main.TestProgram.__init__``, ``unittest.runner.TextTestRunner.run``. 
+Thus the following is suggested.
+  
+  1) Doesn't require any handling, because ``unittest.main.TestProgram`` isn't used
+  2) Set ``sys.warnoptions`` in ``setup.py``
+  3) Call it ``python -Wa -m unittest qxcpjsonrpc.test.suite`` 
 '''
 
 
@@ -10,12 +29,8 @@ import datetime
 import io
 import os.path
 import hashlib
-
-try:
-  from StringIO import StringIO
-except ImportError:
-  # Python 3 compatibility
-  from io import StringIO 
+import warnings
+import sys
 
 import cherrypy
 from cherrypy.lib import auth_basic
@@ -24,7 +39,6 @@ from cherrypy.lib import auth_basic
 try:
   import nose #@UnusedImport
 except ImportError:
-  import sys
   import types
   sys.modules['nose'] = types.ModuleType('nose')
 import cherrypy.test.helper as helper 
@@ -181,7 +195,7 @@ class Service(rpc.Service):
     cherrypy.response.headers['content-type']        = 'application/octet-stream'
     cherrypy.response.headers['content-disposition'] = 'attachment; filename=download.txt'
     
-    result = StringIO()
+    result = io.StringIO()
     result.write(open(os.path.dirname(__file__) + '/fixture/text', 'rb').read().decode())
     
     return result
@@ -202,7 +216,21 @@ class Service(rpc.Service):
     cherrypy.response.headers['content-type'] = 'text/plain'
     
     return dict(hash = hash, passthrough = passthrough)
-  
+
+
+# explicit warning control  
+warnings.resetwarnings()
+warnings.simplefilter('error')
+if sys.version_info >= (3, 0):
+  # qxcpjsonrpc.test.suite, okay for polyglot package 
+  warnings.filterwarnings('ignore', 'Please use assertRegex instead', DeprecationWarning)
+  # qxcpjsonrpc.test.suite: no non-referenced-counting Python implementation targeted
+  warnings.filterwarnings('ignore', 'unclosed file <_io.', ResourceWarning)  # @UndefinedVariable
+  # cherrypy._cperror: reported #1330
+  warnings.filterwarnings('ignore', 'cgi.escape is deprecated, use html.escape instead', DeprecationWarning)
+  # cherrypy.wsgiserver.wsgiserver3: reported #1331
+  warnings.filterwarnings('ignore', 'unclosed <socket.socket object', ResourceWarning)  # @UndefinedVariable
+
 
 delattr(helper.CPWebCase, 'test_gc') # don't want the supplement in a test report
 
